@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::SKIRMESS;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -18,6 +18,25 @@ sub configure {
 
     $self->add_plugins(
 
+        # Check at build/release time if modules are out of date
+        [
+            'PromptIfStale', 'stale modules, build',
+            {
+                phase  => 'build',
+                module => [ $self->meta->name ],
+            }
+        ],
+
+        # Check at build/release time if modules are out of date
+        [
+            'PromptIfStale', 'stale modules, release',
+            {
+                phase             => 'release',
+                check_all_plugins => 1,
+                check_all_prereqs => 1,
+            }
+        ],
+
         # Add contributor names from git to your distribution
         'Git::Contributors',
 
@@ -66,6 +85,14 @@ sub configure {
             }
         ],
 
+        # Prune stuff that you probably don't mean to include
+        [
+            'PruneCruft',
+            {
+                exclude => [qw( .perltidyrc )],
+            }
+        ],
+
         # Decline to build files that appear in a MANIFEST.SKIP-like file
         'ManifestSkip',
 
@@ -132,6 +159,15 @@ sub configure {
         # Add Dist::Zilla authordeps to META files as develop prereqs
         'Prereqs::AuthorDeps',
 
+        # List simple prerequisites
+        [
+            'Prereqs',
+            {
+                '-phase'          => 'develop',
+                $self->meta->name => $self->VERSION,
+            }
+        ],
+
         # Summarize Dist::Zilla configuration into distmeta
         'MetaConfig',
 
@@ -252,9 +288,6 @@ sub configure {
         # Push current branch
         'Git::Push',
 
-        # Update your github repository description from abstract on release
-        'UpdateGitHub',
-
         # Compare data and files at different phases of the distribution build process
         'VerifyPhases',
     );
@@ -268,15 +301,63 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Dist::Zilla::PluginBundle::Author::SKIRMESS - Dist::Zilla configuration the way SKIRMESS does it
+
 =head1 SYNOPSIS
 
   # in dist.ini
   [@Author::SKIRMESS]
 
+=head1 DESCRIPTION
+
+This is a L<Dist::Zilla> PluginBundle.
+
 =head1 USAGE
 
 To use this PluginBundle, just add it to your dist.ini.
 
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS>
+
+  git clone https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS.git
+
+=head1 AUTHOR
+
+Sven Kirmess <sven.kirmess@kzone.ch>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by Sven Kirmess.
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=head1 SEE ALSO
+
+L<Dist::Zilla::PluginBundle::Author::ETHER>,
+L<Dist::Zilla::PluginBundle::DAGOLDEN>,
+L<Dist::Zilla::PluginBundle::Milla>,
+L<Dist::Milla>
+
 =cut
 
 # vim: ts=4 sts=4 sw=4 et: syntax=perl
